@@ -37,19 +37,19 @@ PlayDialog::PlayDialog( TQWidget *parent, bool be_welcome_dialog )
 
    //TODO use the kguiItems from the actions
    mapper->setMapping( o = new KPushButton( KGuiItem( i18n("Play File..."), "folder" ), this ), FILE );
-   connect( o, SIGNAL(clicked()), mapper, SLOT(map()) );
+   connect( o, TQ_SIGNAL(clicked()), mapper, TQ_SLOT(map()) );
    grid->TQLayout::add( o );
 
    mapper->setMapping( o = new KPushButton( KGuiItem( i18n("Play VCD"), "media-optical-cdaudio-unmounted" ), this ), VCD );
-   connect( o, SIGNAL(clicked()), mapper, SLOT(map()) );
+   connect( o, TQ_SIGNAL(clicked()), mapper, TQ_SLOT(map()) );
    grid->TQLayout::add( o );
 
    mapper->setMapping( o = new KPushButton( KGuiItem( i18n("Play DVD"), "media-optical-dvd-unmounted" ), this ), DVD );
-   connect( o, SIGNAL(clicked()), mapper, SLOT(map()) );
+   connect( o, TQ_SIGNAL(clicked()), mapper, TQ_SLOT(map()) );
    grid->TQLayout::add( o );
 
    mapper->setMapping( closeButton, TQDialog::Rejected );
-   connect( closeButton, SIGNAL(clicked()), mapper, SLOT(map()) );
+   connect( closeButton, TQ_SIGNAL(clicked()), mapper, TQ_SLOT(map()) );
 
    createRecentFileWidget( vbox );
 
@@ -59,12 +59,12 @@ PlayDialog::PlayDialog( TQWidget *parent, bool be_welcome_dialog )
    if( be_welcome_dialog ) {
       TQWidget *w = new KPushButton( KStdGuiItem::quit(), this );
       hbox->addWidget( w );
-      connect( w, SIGNAL(clicked()), kapp, SLOT(quit()) );
+      connect( w, TQ_SIGNAL(clicked()), kapp, TQ_SLOT(quit()) );
    }
 
    hbox->addWidget( closeButton );
 
-   connect( mapper, SIGNAL(mapped( int )), SLOT(done( int )) );
+   connect( mapper, TQ_SIGNAL(mapped( int )), TQ_SLOT(done( int )) );
 }
 
 void
@@ -98,7 +98,7 @@ PlayDialog::createRecentFileWidget( TQBoxLayout *layout )
 
    if( lv->childCount() ) {
       layout->addWidget( lv, 1 );
-      connect( lv, SIGNAL(executed( TQListViewItem* )), SLOT(done( TQListViewItem* )) );
+      connect( lv, TQ_SIGNAL(executed( TQListViewItem* )), TQ_SLOT(done( TQListViewItem* )) );
    }
    else
       delete lv;
