@@ -762,7 +762,7 @@ VideoWindow::xineEventListener( void *p, const xine_event_t* xineEvent )
       //FIXME this is not the right way, it will have bugs
       debug() << "XINE_EVENT_MRL_REFERENCE\n";
       engine->m_url = TQString::fromUtf8( ((xine_mrl_reference_data_ext_t*)xineEvent->data)->mrl );
-      TQTimer::singleShot( 0, engine, SLOT(play()) );
+      TQTimer::singleShot( 0, engine, TQ_SLOT(play()) );
       break;
    }
    case XINE_EVENT_DROPPED_FRAMES: debug() << "XINE_EVENT_DROPPED_FRAMES\n"; break;
